****************
Bam Command Line
****************


Standalone Subcommands
======================

These commands can run standalone.

.. %%(pack,remap,deps)%%


Project Subcommands
===================

These commands relate to projects which use a BAM server.

.. %%(init,create,checkout,update,commit,revert,status,list,deps)%%

